@@ -50,7 +50,7 @@ from rattail.gpc import GPC
 from rattail.db.api import get_product_by_upc
 
 from ..db import Session
-from ..forms import AutocompleteFieldRenderer, GPCFieldRenderer, PriceFieldRenderer
+from ..forms import GPCFieldRenderer, BrandFieldRenderer, PriceFieldRenderer
 from . import CrudView
 
 
@@ -225,17 +225,17 @@ class ProductCrud(CrudView):
     def fieldset(self, model):
         fs = self.make_fieldset(model)
         fs.upc.set(renderer=GPCFieldRenderer)
-        fs.brand.set(renderer=AutocompleteFieldRenderer(
-                self.request.route_url('brands.autocomplete')))
+        fs.brand.set(options=[])
         fs.regular_price.set(renderer=PriceFieldRenderer)
         fs.current_price.set(renderer=PriceFieldRenderer)
         fs.configure(
             include=[
                 fs.upc.label("UPC"),
-                fs.brand,
+                fs.brand.with_renderer(BrandFieldRenderer),
                 fs.description,
                 fs.size,
                 fs.department,
+                fs.family,
                 fs.subdepartment,
                 fs.regular_price,
                 fs.current_price,
